@@ -21,12 +21,37 @@ REFERENCES_PATH = Path(esmvaltool_file).absolute().parent / 'references'
 
 
 def add_height2m(cube):
-    """Add scalar coordinate 'height' with value of 2m."""
+    """Add scalar coordinate 'height' with value of 2m.
+
+    Parameters
+    ----------
+    cube: iris.cube.Cube
+        data cube to get the 2m height coordinate.
+
+    Returns
+    -------
+    iris.cube.Cube
+        Returns the cube with new 2m height coordinate.
+    """
     add_scalar_height_coord(cube, height=2.)
 
 
 def add_scalar_height_coord(cube, height=2.):
-    """Add scalar coordinate 'height' with value of `height`m."""
+    """Add scalar coordinate 'height' with value of `height`m.
+
+    Parameters
+    ----------
+    cube: iris.cube.Cube
+        data cube to have the height coordinate added to.
+
+    height: float
+        value for height in meters
+
+    Returns
+    -------
+    iris.cube.Cube
+        Returns the iris cube with new height (value: height) coordinate.
+    """
     logger.debug("Adding height coordinate (%sm)", height)
     height_coord = iris.coords.AuxCoord(
         height,
@@ -40,14 +65,48 @@ def add_scalar_height_coord(cube, height=2.):
 
 @contextmanager
 def constant_metadata(cube):
-    """Do cube math without modifying units etc."""
+    """Do cube math without modifying units, attributes etc.
+
+    Context manager that should be used when operating on a data cube
+    that keeps its metadata constant (units, variable names, attributes etc.).
+    Use as with any other context managers: `with constant_metadata(cube):`
+
+
+    Parameters
+    ----------
+    cube: iris.cube.Cube
+        data cube to be operated on, keeping its
+        metadata constant.
+
+    Returns
+    -------
+    iris.cube.Cube
+        Returns the iris cube that was operated on.
+    """
     metadata = cube.metadata
     yield metadata
     cube.metadata = metadata
 
 
 def convert_timeunits(cube, start_year):
-    """Convert time axis from malformed Year 0."""
+    """Convert time axis from malformed Year 0.
+
+    Changes time coordinate with CMOR-like units of
+    e.g. `months since START_YEAR-01-01`.
+
+    Parameters
+    ----------
+    cube: iris.cube.Cube
+        data cube to have its time coordinate changed.
+
+    start_year: int
+        integer start year as origin of time coordinate
+
+    Returns
+    -------
+    iris.cube.Cube
+        Returns the original iris cube with time coordinate reformatted.
+    """
     # TODO any more weird cases?
     if cube.coord('time').units == 'months since 0000-01-01 00:00:00':
         real_unit = 'months since {}-01-01 00:00:00'.format(str(start_year))
@@ -99,7 +158,7 @@ def fix_coords(cube, overwrite_time_bounds=True, overwrite_lon_bounds=True,
 
     """
     # first fix any completely missing coord var names
-    _fix_dim_coordnames(cube)
+    fix_dim_coordnames(cube)
     # fix individual coords
     for cube_coord in cube.coords():
         # fix time
@@ -108,7 +167,7 @@ def fix_coords(cube, overwrite_time_bounds=True, overwrite_lon_bounds=True,
             cube.coord('time').convert_units(
                 Unit('days since 1950-1-1 00:00:00', calendar='gregorian'))
             if overwrite_time_bounds or not cube.coord('time').has_bounds():
-                _fix_bounds(cube, cube.coord('time'))
+                fix_bounds(cube, cube.coord('time'))
 
         # fix longitude
         if cube_coord.var_name == 'lon':
@@ -119,30 +178,30 @@ def fix_coords(cube, overwrite_time_bounds=True, overwrite_lon_bounds=True,
                     cube_coord.points = \
                         cube_coord.points + 180.
                     if overwrite_lon_bounds or not cube_coord.has_bounds():
-                        _fix_bounds(cube, cube_coord)
+                        fix_bounds(cube, cube_coord)
                     cube.attributes['geospatial_lon_min'] = 0.
                     cube.attributes['geospatial_lon_max'] = 360.
                     nlon = len(cube_coord.points)
-                    _roll_cube_data(cube, nlon // 2, -1)
+                    roll_cube_data(cube, nlon // 2, -1)
 
         # fix latitude
         if cube_coord.var_name == 'lat':
             logger.info("Fixing latitude...")
             if overwrite_lat_bounds or not cube.coord('latitude').has_bounds():
-                _fix_bounds(cube, cube.coord('latitude'))
+                fix_bounds(cube, cube.coord('latitude'))
 
         # fix depth
         if cube_coord.var_name == 'lev':
             logger.info("Fixing depth...")
             if overwrite_lev_bounds or not cube.coord('depth').has_bounds():
-                _fix_bounds(cube, cube.coord('depth'))
+                fix_bounds(cube, cube.coord('depth'))
 
         # fix air_pressure
         if cube_coord.var_name == 'air_pressure':
             logger.info("Fixing air pressure...")
             if overwrite_airpres_bounds \
                     or not cube.coord('air_pressure').has_bounds():
-                _fix_bounds(cube, cube.coord('air_pressure'))
+                fix_bounds(cube, cube.coord('air_pressure'))
 
     # remove CS
     cube.coord('latitude').coord_system = None
@@ -152,14 +211,33 @@ def fix_coords(cube, overwrite_time_bounds=True, overwrite_lon_bounds=True,
 
 
 def fix_var_metadata(cube, var_info):
-    """Fix var metadata from CMOR table."""
+    """Fix var metadata from CMOR table.
+
+    Sets var_name, long_name, standard_name and units
+    in accordance with CMOR standards from specific CMOR table.
+
+    Parameters
+    ----------
+    cube: iris.cube.Cube
+        data cube to have its metadata changed.
+
+    var_info: class
+        CMOR table object holding the information to be changed in the cube.
+        Attributes like standard_name, var_name, long_name are used to
+        set the new metadata in the input cube.
+
+    Returns
+    -------
+    iris.cube.Cube
+        Returns the masked iris cube.
+    """
     if var_info.standard_name == '':
         cube.standard_name = None
     else:
         cube.standard_name = var_info.standard_name
     cube.var_name = var_info.short_name
     cube.long_name = var_info.long_name
-    _set_units(cube, var_info.units)
+    set_units(cube, var_info.units)
     return cube
 
 
@@ -188,8 +266,29 @@ def read_cmor_config(dataset):
 
 
 def save_variable(cube, var, outdir, attrs, **kwargs):
-    """Saver function."""
-    _fix_dtype(cube)
+    """Saver function.
+
+    Saves iris cubes (data variables) in CMOR-standard named files.
+
+    Parameters
+    ----------
+    cube: iris.cube.Cube
+        data cube to be saved.
+
+    var: str
+        Variable short_name e.g. ts or tas.
+
+    outdir: str
+        root directory where the file will be saved.
+
+    attrs: dict
+        dictionary holding cube metadata attributes like
+        project_id, version etc.
+
+    **kwargs: kwargs
+        Keyword arguments to be passed to `iris.save`
+    """
+    fix_dtype(cube)
     # CMOR standard
     try:
         time = cube.coord('time')
@@ -302,7 +401,7 @@ def var_name_constraint(var_name):
     return iris.Constraint(cube_func=lambda c: c.var_name == var_name)
 
 
-def _fix_bounds(cube, dim_coord):
+def fix_bounds(cube, dim_coord):
     """Reset and fix all bounds."""
     if len(cube.coord(dim_coord).points) > 1:
         if cube.coord(dim_coord).has_bounds():
@@ -315,7 +414,7 @@ def _fix_bounds(cube, dim_coord):
     return cube
 
 
-def _fix_dim_coordnames(cube):
+def fix_dim_coordnames(cube):
     """Perform a check on dim coordinate names."""
     # first check for CMOR standard coord;
     for coord in cube.coords():
@@ -364,7 +463,7 @@ def _fix_dim_coordnames(cube):
     return cube
 
 
-def _fix_dtype(cube):
+def fix_dtype(cube):
     """Fix `dtype` of a cube and its coordinates."""
     if cube.dtype != np.float32:
         logger.info("Converting data type of data from '%s' to 'float32'",
@@ -385,13 +484,13 @@ def _fix_dtype(cube):
                                                       casting='same_kind')
 
 
-def _roll_cube_data(cube, shift, axis):
+def roll_cube_data(cube, shift, axis):
     """Roll a cube data on specified axis."""
     cube.data = da.roll(cube.core_data(), shift, axis=axis)
     return cube
 
 
-def _set_units(cube, units):
+def set_units(cube, units):
     """Set units in compliance with cf_unit."""
     special = {'psu': 1.e-3, 'Sv': '1e6 m3 s-1'}
     if units in list(special.keys()):
