@@ -1,16 +1,20 @@
 """Module that provides common plot functions."""
 
 from ._plot import (
-    get_path_to_mpl_style,
     get_dataset_style,
-    quickplot,
+    get_path_to_mpl_style,
+    global_contourf,
+    global_pcolormesh,
     multi_dataset_scatterplot,
+    quickplot,
     scatterplot,
 )
 
 __all__ = [
     'get_path_to_mpl_style',
     'get_dataset_style',
+    'global_contourf',
+    'global_pcolormesh',
     'quickplot',
     'multi_dataset_scatterplot',
     'scatterplot',
