@@ -41,11 +41,14 @@ def balances(cfg, wdir, plotpath, filena, name, model):
     enthalpy transports are also provided.
 
     Arguments:
-    - wdir: the working directory;
-    - plotpath: the path where the plot has to be saved;
-    - filena: the files containing input fields;
-    - name: the name of the variable associated with the input field;
-    - model: the name of the model to be analysed;
+    ---------
+    wdir: the working directory;
+    plotpath: the path where the plot has to be saved;
+    filena: the files containing input fields;
+    name: the name of the variable associated with the input field;
+    model: the name of the model to be analysed;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     cdo = Cdo()
     provlog = ProvenanceLogger(cfg)
@@ -72,7 +75,7 @@ def balances(cfg, wdir, plotpath, filena, name, model):
             'TOA Energy Budget', 'Atmospheric Energy Budget',
             'Surface Energy Budget'
         ]
-        transpty = (-6E15, 6E15)
+        transpty = (-6.75E15, 6.75E15)
         coords = [dims[0], dims[1]]
         plot_climap_eb(model, pdir, coords, tmean, ext_name)
         fig = plt.figure()
@@ -148,9 +151,12 @@ def balances(cfg, wdir, plotpath, filena, name, model):
         axi.plot(dims[3], timeser[i_f, :, 2], 'b', label='NH')
         plt.title('Annual mean {}'.format(ext_name[i_f]))
         plt.xlabel('Years')
-        plt.ylabel('[W/m2]')
+        if ext_name[i_f] == 'Water mass budget':
+            plt.ylabel('[Kg m-2 s-1]')
+        else:
+            plt.ylabel('[W/m2]')
         axi.legend(loc='upper center',
-                   bbox_to_anchor=(0.5, -0.07),
+                   bbox_to_anchor=(0.5, -0.13),
                    shadow=True,
                    ncol=3)
         plt.tight_layout()
@@ -163,11 +169,14 @@ def entropy(plotpath, filename, name, ext_name, model):
     """Plot everything rleated to annual mean maps of mat. entr. prod.
 
     Arguments:
-    - plotpath: the path where the plot has to be saved;
-    - filename: the file containing input fields;
-    - name: the name of the variable associated with the input field;
-    - ext_name: the long name of the input field
-    - model: the name of the model to be analysed;
+    ---------
+    plotpath: the path where the plot has to be saved;
+    filename: the file containing input fields;
+    name: the name of the variable associated with the input field;
+    ext_name: the long name of the input field
+    model: the name of the model to be analysed;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     pdir = plotpath
     if ext_name == 'Vertical entropy production':
@@ -182,20 +191,18 @@ def entropy(plotpath, filename, name, ext_name, model):
     elif ext_name == 'Evaporation entropy production':
         rangec = [0, 1]
         c_m = 'YlOrBr'
-    elif ext_name == 'Rainfall precipitation entropy production':
+    elif ext_name == 'Rainfall entropy production':
         rangec = [0, 1]
         c_m = 'YlOrBr'
-    elif ext_name == 'Snowfall precipitation entropy production':
+    elif ext_name == 'Snowfall entropy production':
         rangec = [0, 0.25]
         c_m = 'YlOrBr'
-    elif ext_name == 'Snow melting entropy production':
+    elif ext_name == 'Snowmelt entropy production':
         rangec = [0, 0.05]
         c_m = 'YlOrBr'
     elif ext_name == 'Potential energy entropy production':
         rangec = [0, 0.1]
         c_m = 'YlOrBr'
-    else:
-        quit()
     with Dataset(filename) as dataset:
         var = dataset.variables[name][:, :, :]
         lats = dataset.variables['lat'][:]
@@ -204,7 +211,7 @@ def entropy(plotpath, filename, name, ext_name, model):
     fig = plt.figure()
     axi = plt.axes(projection=ccrs.PlateCarree())
     coords = [lons, lats]
-    title = 'Climatological Mean {}'.format(ext_name)
+    title = '{} (mW m-2 K-1)'.format(ext_name)
     plot_climap(axi, coords, tmean, title, rangec, c_m)
     plt.savefig(pdir + '/{}_{}_climap.png'.format(model, name))
     plt.close(fig)
@@ -214,9 +221,17 @@ def global_averages(nsub, filena, name):
     """Compute zonal mean, global mean, time mean averages.
 
     Arguments:
-    - nsub: the number of variables for which averages must be computed;
-    - filena: the name of the file containing the variable (without extension);
-    - name: the names of the variables;
+    ---------
+    nsub: the number of variables for which averages must be computed;
+    filena: the name of the file containing the variable (without extension);
+    name: the names of the variables;
+
+    Returns
+    -------
+    Dimensions, number of dimensions, a global mean map, a Hovmoller plot, and
+    a time series of annual global mean values.
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     sep = '.nc'
     filena[0] = filena[0].split(sep, 1)[0]
@@ -258,9 +273,16 @@ def hemean(hem, lat, inp):
     """Compute hemispheric averages.
 
     Arguments:
-    - hem: a parameter for the choice of the hemisphere (1 stands for SH);
-    - lat: latitude (in degrees);
-    - inp: input field;
+    ---------
+    hem: a parameter for the choice of the hemisphere (1 stands for SH);
+    lat: latitude (in degrees);
+    inp: input field;
+
+    Returns
+    -------
+    A time series of annual hemispheric mean values.
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     j_end = np.shape(inp)[1]
     zmn = latwgt(lat, inp)
@@ -282,18 +304,19 @@ def init_plotentr(model, pdir, flist):
     """Define options for plotting maps of entropy production components.
 
     Arguments:
-    - model: the name of the model;
-    - path: the path to the plots directory;
-    - flist: a list of files containing the components of the entropy
-      production with the direct method;
+    ---------
+    model: the name of the model;
+    path: the path to the plots directory;
+    flist: a list of files containing the components of the entropy production
+           with the direct method;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     entropy(pdir, flist[0], 'ssens', 'Sensible Heat entropy production', model)
     entropy(pdir, flist[1], 'sevap', 'Evaporation entropy production', model)
-    entropy(pdir, flist[2], 'srain',
-            'Rainfall precipitation entropy production', model)
-    entropy(pdir, flist[3], 'ssnow',
-            'Snowfall precipitation entropy production', model)
-    entropy(pdir, flist[4], 'smelt', 'Snow melting entropy production', model)
+    entropy(pdir, flist[2], 'srain', 'Rainfall entropy production', model)
+    entropy(pdir, flist[3], 'ssnow', 'Snowfall entropy production', model)
+    entropy(pdir, flist[4], 'smelt', 'Snowmelt entropy production', model)
     entropy(pdir, flist[5], 'spotp', 'Potential energy entropy production',
             model)
 
@@ -302,8 +325,15 @@ def latwgt(lat, t_r):
     """Compute weighted average over latitudes.
 
     Arguments:
-    - lat: latitude (in degrees);
-    - tr: the field to be averaged (time,lat);
+    ---------
+    lat: latitude (in degrees);
+    tr: the field to be averaged (time,lat);
+
+    Returns
+    -------
+    A latitudinal mean weighted by the cosine of latitudes.
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     p_i = math.pi
     conv = 2 * p_i / 360
@@ -319,26 +349,53 @@ def latwgt(lat, t_r):
     return tr2
 
 
+def lec_plot(model, pdir, lect):
+    """Define options for plotting maps of entropy production components.
+
+    Arguments:
+    ---------
+    model: the name of the model;
+    path: the path to the plots directory;
+    lect: a time series of annual mean LEC intensities;
+
+    @author: Valerio Lembo, Hamburg University, 2019.
+    """
+    fig = plt.figure()
+    axi = plt.subplot(111)
+    time = np.linspace(0, len(lect), len(lect))
+    axi.plot(time, lect, 'k')
+    plt.title('Annual mean LEC intensity for {}'.format(model))
+    plt.xlabel('Years')
+    plt.ylabel('[W/m2]')
+    plt.tight_layout()
+    plt.grid()
+    plt.savefig(pdir + '/{}_lec_timeser.png'.format(model))
+    plt.close(fig)
+
+
 def plot_climap_eb(model, pdir, coords, tmean, ext_name):
     """Plot climatological mean maps of TOA, atmospheric, oceanic energy budg.
 
     Arguments:
-    - model: the name of the model;
-    - pdir: a plots directory;
-    - coords: the lon and lat coordinates;
-    - tmean: the climatological mean (3,lat,lon) maps of the three budgets;
-    - ext_name: the extended name of the budget, to be used for the title;
+    ---------
+    model: the name of the model;
+    pdir: a plots directory;
+    coords: the lon and lat coordinates;
+    tmean: the climatological mean (3,lat,lon) maps of the three budgets;
+    ext_name: the extended name of the budget, to be used for the title;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     rangect = [-100, 100]
     fig = plt.figure(figsize=(12, 22))
     axi = plt.subplot(311, projection=ccrs.PlateCarree())
-    title = 'Climatological Mean {}'.format(ext_name[0])
+    title = '{} (W/m2)'.format(ext_name[0])
     plot_climap(axi, coords, tmean[0, :, :], title, rangect, 'bwr')
     axi = plt.subplot(312, projection=ccrs.PlateCarree())
-    title = 'Climatological Mean {}'.format(ext_name[1])
+    title = '{} (W/m2)'.format(ext_name[1])
     plot_climap(axi, coords, tmean[1, :, :], title, rangect, 'bwr')
     axi = plt.subplot(313, projection=ccrs.PlateCarree())
-    title = 'Climatological Mean {}'.format(ext_name[2])
+    title = '{} (W/m2)'.format(ext_name[2])
     plot_climap(axi, coords, tmean[2, :, :], title, rangect, 'bwr')
     plt.savefig(pdir + '/{}_energy_climap.png'.format(model))
     plt.close(fig)
@@ -348,24 +405,27 @@ def plot_climap_wm(model, pdir, coords, tmean, ext_name, name):
     """Plot climatological mean maps of water mass and latent energy budgets.
 
     Arguments:
-    - model: the name of the model;
-    - pdir: a plots directory;
-    - coords: the lon and lat coordinates;
-    - tmean: the climatological mean (3,lat,lon) maps of the three budgets;
-    - ext_name: the extended name of the budget, to be used for the title;
-    - name: the variable name, used for the file name of the figure;
+    ---------
+    model: the name of the model;
+    pdir: a plots directory;
+    coords: the lon and lat coordinates;
+    tmean: the climatological mean (3,lat,lon) maps of the three budgets;
+    ext_name: the extended name of the budget, to be used for the title;
+    name: the variable name, used for the file name of the figure;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     rangecw = [-1E-4, 1E-4]
     rangecl = [-150, 150]
     fig = plt.figure()
     axi = plt.subplot(111, projection=ccrs.PlateCarree())
-    title = 'Climatological Mean {}'.format(ext_name[0])
+    title = '{} (Km m-2 s-1)'.format(ext_name[0])
     plot_climap(axi, coords, tmean[0, :, :], title, rangecw, 'bwr')
     plt.savefig(pdir + '/{}_{}_climap.png'.format(model, name[0]))
     plt.close(fig)
     fig = plt.figure()
     axi = plt.subplot(111, projection=ccrs.PlateCarree())
-    title = 'Climatological Mean {}'.format(ext_name[1])
+    title = '{} (W/m2)'.format(ext_name[1])
     plot_climap(axi, coords, tmean[1, :, :], title, rangecl, 'bwr')
     plt.savefig(pdir + '/{}_{}_climap.png'.format(model, name[1]))
     plt.close(fig)
@@ -375,12 +435,15 @@ def plot_climap(axi, coords, fld, title, rrange, c_m):
     """Plot very colourful maps.
 
     Arguments:
-    - axi: an axis identifier;
-    - coords: the lon and lat coordinates;
-    - fld: the field to be plotted;
-    - title: the title to appear on the figure;
-    - rrange: the range for the color bar;
-    - c_m: a color map identifier;
+    ---------
+    axi: an axis identifier;
+    coords: the lon and lat coordinates;
+    fld: the field to be plotted;
+    title: the title to appear on the figure;
+    rrange: the range for the color bar;
+    c_m: a color map identifier;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     axi.coastlines()
     lons = np.linspace(0, 360, len(coords[0])) - (coords[0][1] - coords[0][0])
@@ -393,8 +456,7 @@ def plot_climap(axi, coords, fld, title, rrange, c_m):
                cmap=c_m,
                antialiaseds='True')
     plt.colorbar()
-    plt.title(title)
-    plt.grid()
+    plt.title(title, fontsize=14)
 
 
 def plot_ellipse(semimaj, semimin, phi, x_cent, y_cent, a_x):
@@ -403,19 +465,14 @@ def plot_ellipse(semimaj, semimin, phi, x_cent, y_cent, a_x):
     This method plots ellipses with matplotlib.
 
     Arguments:
-    - semimaj: the length of the major axis;
-    - semimin: the length of the minor axis;
-    - phi: the tilting of the semimaj axis;
-    - (x_cent, y_cent): the coordinates of the ellipse centre;
-    - theta_num: the number of points to sample along ellipse from 0-2pi;
-    - ax: an object containing the axis properties;
-    - plot_kwargs: matplotlib.plot keyword arguments;
-    - fill: a flag to fill the inside of the ellipse;
-    - fill_kwargs: keyword arguments for matplotlib.fill;
-    - data_out: a flag to return the ellipse samples without plotting;
-    - cov: a 2x2 covariance matrix;
-    - mass_level: a number defining the fractional probability enclosed, if
-    cov is given;
+    ---------
+    semimaj: the length of the major axis;
+    semimin: the length of the minor axis;
+    phi: the tilting of the semimaj axis;
+    x_cent, y_cent: the coordinates of the ellipse centre;
+    a_x: an object containing the axis properties;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     theta = np.linspace(0, 2 * np.pi, 100)
     r_r = 1 / np.sqrt((np.cos(theta))**2 + (np.sin(theta))**2)
@@ -440,10 +497,13 @@ def plot_1m_scatter(model, pdir, lat_maxm, tr_maxm):
     in the NH (c) and SH (d).
 
     Arguments:
-    - model: the name of the model;
-    - pdir: a plots directory;
-    - lat_maxm: the positions of the peaks;
-    - tr_maxm: the magnitudes of the peaks;
+    ---------
+    model: the name of the model;
+    pdir: a plots directory;
+    lat_maxm: the positions of the peaks;
+    tr_maxm: the magnitudes of the peaks;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     fig = plt.figure()
     fig.set_size_inches(12, 12)
@@ -486,12 +546,16 @@ def plot_1m_transp(lats, yval, ylim, strings):
     transports on the same panel.
 
     Arguments:
-    - lats: the latitudinal dimension as a 1D array;
-    - yval: the meridional enthalpy transports as a 2D array (3,lat), where
-    row 1 is the total, row 2 the atmospheric, row 3 the oceanic transport;
-    - ylim: a range for the y-axis;
-    - strings: a list of strings containing the title of the figure, the names
-    of the x and y axes;
+    ---------
+    lats: the latitudinal dimension as a 1D array;
+    yval: the meridional enthalpy transports as a 2D array (3,lat), where
+          row 1 is the total, row 2 the atmospheric, row 3 the oceanic
+          transport;
+    ylim: a range for the y-axis;
+    strings: a list of strings containing the title of the figure, the names
+             of the x and y axes;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     plt.subplot(111)
     plt.plot(lats, yval)
@@ -514,10 +578,13 @@ def plot_mm_ebscatter(pdir, eb_list):
     1sigma uncertainty range;
 
     Arguments:
-    - pdir: a plots directory;
-    - eb_list: a list containing the TOA, atmospheri and surface energy budgets
-    as a 2D array (model, 2), with the first column being the mean value and
-    the second column being the inter-annual variance;
+    ---------
+    pdir: a plots directory;
+    eb_list: a list containing the TOA, atmospheri and surface energy budgets
+             as a 2D array (model, 2), with the first column being the mean
+             value and the second column being the inter-annual variance;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     toab_all = eb_list[0]
     atmb_all = eb_list[1]
@@ -569,12 +636,15 @@ def plot_mm_scatter(axi, varlist, title, xlabel, ylabel):
     ellipse encompassing the 1sigma uncertainty around the multi-model mean.
 
     Arguments:
-    - axi: an axis identifier;
-    - varlist: a list containing the array for the x and y values (they have to
-    be the same length);
-    - title: a string containing the title of the plot;
-    - xlabel: a string containing the x-axis label;
-    - ylabel: a string containing the y-axis label;
+    ---------
+    axi: an axis identifier;
+    varlist: a list containing the array for the x and y values (they have to
+             be the same length);
+    title: a string containing the title of the plot;
+    xlabel: a string containing the x-axis label;
+    ylabel: a string containing the y-axis label;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     xval = varlist[0]
     yval = varlist[1]
@@ -603,7 +673,8 @@ def plot_mm_scatter(axi, varlist, title, xlabel, ylabel):
                      xytext=(xval[i_m] + d_x, yval[i_m] + d_y),
                      fontsize=12)
     axi.tick_params(axis='both', which='major', labelsize=12)
-    plt.subplots_adjust(hspace=.3)
+    axi.margins(0.002)
+    plt.axis('auto')
     plt.grid()
 
 
@@ -615,20 +686,20 @@ def plot_mm_scatter_spec(axi, varlist, title, xlabel, ylabel):
     encompassing the 1sigma uncertainty around the multi-model mean.
 
     Arguments:
-    - axi: an axis identifier;
-    - varlist: a list containing the array for the x and y values (they have to
-    be the same length);
-    - title: a string containing the title of the plot;
-    - xlabel: a string containing the x-axis label;
-    - ylabel: a string containing the y-axis label;
+    ---------
+    axi: an axis identifier;
+    varlist: a list containing the array for the x and y values (they have to
+             be the same length);
+    title: a string containing the title of the plot;
+    xlabel: a string containing the x-axis label;
+    ylabel: a string containing the y-axis label;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     xval = varlist[0]
     yval = varlist[1]
-    axi.set_figsize = (50, 50)
     xrang = abs(max(xval) - min(xval))
     yrang = abs(max(yval) - min(yval))
-    plt.xlim(min(xval) - 0.1 * xrang, max(xval) + 0.1 * xrang)
-    plt.ylim(min(yval) - 0.1 * yrang, max(yval) + 0.1 * yrang)
     x_x = np.linspace(min(xval) - 0.1 * xrang, max(xval) + 0.1 * xrang, 10)
     y_y = np.linspace(min(yval) - 0.1 * yrang, max(yval) + 0.1 * yrang, 10)
     x_m, y_m = np.meshgrid(x_x, y_y)
@@ -655,10 +726,14 @@ def plot_mm_summaryscat(pdir, summary_varlist):
     - (f) Baroclinic efficiency vs. emission temperature;
 
     Arguments:
-    - pdir: a plots directory;
-    - summary_varlist: a list containing the quantities to be plotted as a 1D
-    (model) array, or a 2D array (model, 2), with the first column being the
-    mean value and the second column being the inter-annual variance;
+    ---------
+    pdir: a plots directory;
+    summary_varlist: a list containing the quantities to be plotted as a 1D
+                     (model) array, or a 2D array (model, 2), with the first
+                     column being the mean value and the second column being
+                     the inter-annual variance;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     atmb_all = summary_varlist[0]
     baroceff_all = summary_varlist[1]
@@ -670,7 +745,7 @@ def plot_mm_summaryscat(pdir, summary_varlist):
     vertentr_all = summary_varlist[7]
     indentr_all = horzentr_all[:, 0] + vertentr_all[:, 0]
     fig = plt.figure()
-    fig.set_size_inches(12, 22)
+    fig.set_size_inches(14, 22)
     axi = plt.subplot(321)
     title = '(a) TOA vs. atmospheric energy budget'
     xlabel = 'R_t [W m-2]'
@@ -679,33 +754,36 @@ def plot_mm_summaryscat(pdir, summary_varlist):
     plot_mm_scatter(axi, varlist, title, xlabel, ylabel)
     axi = plt.subplot(322)
     title = '(b) Baroclinic efficiency vs. Intensity of LEC'
-    xlabel = 'Eta'
+    xlabel = r'$\eta$'
     ylabel = 'W [W/m2]'
     varlist = [baroceff_all, lec_all[:, 0]]
     plot_mm_scatter(axi, varlist, title, xlabel, ylabel)
     axi = plt.subplot(323)
     title = '(c) Vertical vs. horizontal component'
-    xlabel = 'S_hor [W m-2 K-1]'
-    ylabel = 'S_ver [W m-2 K-1]'
+    xlabel = r'S$_{hor}$ [W m-2 K-1]'
+    ylabel = r'S$_{ver}$ [W m-2 K-1]'
     varlist = [horzentr_all[:, 0], vertentr_all[:, 0]]
     plot_mm_scatter_spec(axi, varlist, title, xlabel, ylabel)
     axi = plt.subplot(324)
     title = '(d) Indirect vs. direct method'
-    xlabel = 'S_ind [W m-2 K-1]'
-    ylabel = 'S_dir [W m-2 K-1]'
+    xlabel = r'S$_{ind}$ [W m-2 K-1]'
+    ylabel = r'S$_{dir}$ [W m-2 K-1]'
     varlist = [indentr_all, matentr_all[:, 0]]
     plot_mm_scatter(axi, varlist, title, xlabel, ylabel)
+    axi.set(xlim=(min(indentr_all) - 0.003, max(indentr_all) + 0.003),
+            ylim=(min(matentr_all[:, 0]) - 0.003,
+                  max(matentr_all[:, 0]) + 0.003))
     axi = plt.subplot(325)
     title = '(e) Indirect vs. emission temperature'
-    xlabel = 'T_E [K]'
-    ylabel = 'S_mat [W m-2 K-1]'
+    xlabel = r'T$_E$ [K]'
+    ylabel = r'S$_{mat}$ [W m-2 K-1]'
     varlist = [te_all, indentr_all]
     plot_mm_scatter(axi, varlist, title, xlabel, ylabel)
     axi = plt.subplot(326)
     title = '(f) Baroclinic efficiency vs. emission temperature'
-    xlabel = 'T_E [K]'
-    ylabel = 'Eta'
-    varlist = [te_all, indentr_all]
+    xlabel = r'T$_E$ [K]'
+    ylabel = r'$\eta$'
+    varlist = [te_all, baroceff_all]
     plot_mm_scatter(axi, varlist, title, xlabel, ylabel)
     oname = pdir + '/scatters_summary.png'
     plt.savefig(oname)
@@ -719,14 +797,17 @@ def plot_mm_transp(model_names, wdir, pdir):
     enthalpy transports, respectively.
 
     Arguments:
-    - model_names: a list of model names contained in the ensemble;
-    - wdir: a working directory;
-    - pdir: a plots directory;
+    ---------
+    model_names: a list of model names contained in the ensemble;
+    wdir: a working directory;
+    pdir: a plots directory;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     fig = plt.figure()
     fig.set_size_inches(12, 22)
     axi = plt.subplot(311)
-    yrange = [-6.25E15, 6.25E15]
+    yrange = [-6.75E15, 6.75E15]
     plot_mm_transp_panel(model_names, wdir, axi, 'total', yrange)
     axi = plt.subplot(312)
     plot_mm_transp_panel(model_names, wdir, axi, 'atmos', yrange)
@@ -742,11 +823,14 @@ def plot_mm_transp_panel(model_names, wdir, axi, domn, yrange):
     """Plot a meridional section of enthalpy transport from a model ensemble.
 
     Arguments:
-    - model_names: a list of model names contained in the ensemble;
-    - wdir: a working directory;
-    - axis: the axis of the pllot;
-    - domn: the domain (total, atmospheric or oceanic);
-    - yrange: a range for the y-axis;
+    ---------
+    model_names: a list of model names contained in the ensemble;
+    wdir: a working directory;
+    axis: the axis of the pllot;
+    domn: the domain (total, atmospheric or oceanic);
+    yrange: a range for the y-axis;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     axi.set_figsize = (50, 50)
     for model in model_names:
@@ -774,16 +858,16 @@ def pr_output(varout, filep, nc_f, nameout, latn):
     new one.
 
     Arguments:
-        - varout: the field to be stored, with shape (time,level,lat,lon);
-        - filep: the existing dataset, from where the metadata are
-          retrieved. Coordinates time,level, lat and lon have to be the
-          same dimension as the fields to be saved to the new files;
-        - nc_f: the name of the output file;
-        - nameout: the name of the variable to be saved;
-        - latn: the name of the latitude dimension;
+    ---------
+    varout: the field to be stored, with shape (time,level,lat,lon);
+    filep: the existing dataset, from where the metadata are retrieved.
+           Coordinates time,level, lat and lon have to be the same dimension
+           as the fields to be saved to the new files;
+    nc_f: the name of the output file;
+    nameout: the name of the variable to be saved;
+    latn: the name of the latitude dimension;
 
-    PROGRAMMER(S)
-        Chris Slocum (2014), modified by Valerio Lembo (2018).
+    @author: Chris Slocum (2014), modified by Valerio Lembo (2018).
     """
     fourc = fourier_coefficients
     nc_fid = Dataset(filep, 'r')
@@ -810,9 +894,16 @@ def transport(zmean, gmean, lat):
     """Integrate the energy/water mass budgets to obtain meridional transp.
 
     Arguments:
-    - zmean: zonal mean input fields;
-    - gmean: the global mean of the input fields;
-    - lat: a latitudinal array (in degrees of latitude);
+    ---------
+    zmean: zonal mean input fields;
+    gmean: the global mean of the input fields;
+    lat: a latitudinal array (in degrees of latitude);
+
+    Returns
+    -------
+    A zonal mean meridional heat transport.
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     p_i = math.pi
     dlat = np.zeros(len(lat))
@@ -838,10 +929,17 @@ def transp_max(lat, transp, lim):
     """Obtain transport peak magnitude and location from interpolation.
 
     Arguments:
-    - lat: a latitudinal array;
-    - transp: the meridional transport a 1D array (lat);
-    - lim: limits to constrain the peak search in
-    (necessary for ocean transp.)
+    ---------
+    lat: a latitudinal array;
+    transp: the meridional transport a 1D array (lat);
+    lim: limits to constrain the peak search in (necessary for ocean transp.)
+
+    Returns
+    -------
+    The magnitude and location of the meridional heat transports in the
+    atmosphere, oceans and in total, for every year.
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     deriv = np.gradient(transp)
     x_c = zerocross1d(lat, deriv)
@@ -865,11 +963,19 @@ def transports_preproc(lats, yrs, lim, transp):
     each time through the function transp_max and stores them in a list.
 
     Arguments:
-    - lats: a latitudinal array;
-    - yrs: the number of years through which iterating;
-    - lim: the range (-lim,lim) in which the function transp_max has to search
+    ---------
+    lats: a latitudinal array;
+    yrs: the number of years through which iterating;
+    lim: the range (-lim,lim) in which the function transp_max has to search
     for the peaks;
-    - transp: the array containing the transport;
+    transp: the array containing the transport;
+
+    Returns
+    -------
+    The zonal mean meridional heat transport averaged over time, a list
+    containing the magnitude and location of the peaks at every timestep.
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     transpp = transp[1]
     transp_mean = np.nanmean(transpp, axis=0)
@@ -890,12 +996,14 @@ def transports_preproc(lats, yrs, lim, transp):
 
 
 def varatts(w_nc_var, varname):
-    """Add attibutes to the variables, depending on name and time res.
+    """Add attributes to the variables, depending on name and time res.
 
     Arguments:
-    - w_nc_var: a variable object;
-    - varname: the name of the variable, among total, atmos, ocean, wmb,
-    latent;
+    ---------
+    w_nc_var: a variable object;
+    varname: the name of the variable, among total, atmos, ocean, wmb, latent;
+
+    @author: Valerio Lembo, Hamburg University, 2018.
     """
     if varname == 'total':
         w_nc_var.setncatts({
@@ -940,8 +1048,13 @@ def zerocross1d(x_x, y_y):
     or not they are zero.
 
     Arguments:
+    ---------
     x_x, y_y : arrays. Ordinate and abscissa data values.
 
+    Returns
+    -------
+    The location at which the y_y crosses zero.
+
     Credits:
     The PyA group (https://github.com/sczesla/PyAstronomy).
     Modified by Valerio Lembo (valerio.lembo@uni-hamburg.de).
